@@ -9,8 +9,7 @@ optimization framework from :class:`~optimization.OptimizationObject`.
 
 import logging
 
-from commonscripts import (update_attributes, getattrL, flatten, 
-    quiet, set_trace)
+from commonscripts import (update_attributes, getattrL, flatten, set_trace)
 from config import user_config
 
 from optimization import (value, OptimizationObject,
@@ -81,8 +80,6 @@ class Load(OptimizationObject):
     def __str__(self):
         return 'd{ind}'.format(ind=self.index)
 
-    def __int__(self):
-        return self.index
 
     def get_scheduled_output(self, time):
         return float(self.schedule.ix[time])
@@ -247,7 +244,7 @@ class PowerSystem(OptimizationProblem):
         self.reserve_required = (self.reserve_fixed > 0) or \
             (self.reserve_load_fraction > 0.0)
         
-        if lines is None:
+        if lines is None:  # pragma: no cover
             lines = []
 
         buses = self.make_buses_list(loads, generators)
@@ -394,10 +391,10 @@ class PowerSystem(OptimizationProblem):
     def get_generator_with_scenarios(self):
         gens = filter(lambda gen: getattr(gen, 'is_stochastic',
                       False), self.generators())
-        if len(gens) > 1:
+        if len(gens) > 1:  # pragma: no cover
             raise NotImplementedError(
                 'Dont handle the case of multiple stochastic generators')
-        elif len(gens) == 0:
+        elif len(gens) == 0:  # pragma: no cover
             return []
         else:
             return gens[0]
@@ -431,7 +428,7 @@ class PowerSystem(OptimizationProblem):
         for gen in self.generators():
             finalstatus = getattr(gen, 'finalstatus', {})
             if finalstatus:
-                gen.set_initial_condition(time=initTime, **finalstatus)
+                gen.set_initial_condition(**finalstatus)
                 del gen.finalstatus
         return
 
@@ -527,7 +524,7 @@ class PowerSystem(OptimizationProblem):
 
         # recalc the power balance constraint
         for bus in self.buses:
-            for time in times:
+            for time in const_times:
                 bus._remove_component('power balance', time)
             bus.create_constraints(const_times,
                 self.Bmatrix, self.buses, include_children=False)
@@ -659,7 +656,7 @@ class PowerSystem(OptimizationProblem):
                 names.append(gen.power().name)
         self._fix_variables(names)
 
-    def debug_infeasible(self, times, resolve_sln=None):
+    def debug_infeasible(self, times, resolve_sln=None):  # pragma: no cover
         generators = self.generators()
         if resolve_sln:
             windgen = self.get_generator_with_observed()
